@@ -1,11 +1,6 @@
 from PyObjCTools.TestSupport import *
 from CoreText import *
 
-try:
-    unicode
-except NameError:
-    unicode = str
-
 class TestCTFontManagerErrors (TestCase):
     @min_os_level("10.6")
     def testConstants10_6(self):
@@ -20,7 +15,7 @@ class TestCTFontManagerErrors (TestCase):
 
         self.assertEqual(kCTFontManagerErrorNotRegistered, 201)
         self.assertEqual(kCTFontManagerErrorInUse, 202)
-        self.assertEqual(kCTFontManagerErrorSystemRequired, 202)
+        self.assertEqual(kCTFontManagerErrorSystemRequired, 203)
 
 
 if __name__ == "__main__":
